@@ -3,11 +3,11 @@
  *
  * File:    pcap_capture.c
  *
- * Author:  Damien S. Stuart
- *
  * Purpose: The pcap capture routines for fwknopd.
  *
- * Copyright 2010-2013 Damien Stuart (dstuart@dstuart.org)
+ *  Fwknop is developed primarily by the people listed in the file 'AUTHORS'.
+ *  Copyright (C) 2009-2014 fwknop developers and contributors. For a full
+ *  list of contributors, see the file 'CREDITS'.
  *
  *  License (GNU General Public License):
  *
@@ -28,12 +28,13 @@
  *
  *****************************************************************************
 */
+
+
 #include <pcap.h>
 
 #include "fwknopd_common.h"
 #include "pcap_capture.h"
 #include "process_packet.h"
-#include "sig_handler.h"
 #include "fw_util.h"
 #include "log_msg.h"
 #include "fwknopd_errors.h"
@@ -44,6 +45,8 @@
   #include <sys/wait.h>
 #endif
 
+#if USE_LIBPCAP
+
 /* The pcap capture routine.
 */
 int
@@ -247,24 +250,10 @@ pcap_capture(fko_srv_options_t *opts)
             got_sigchld = 0;
         }
 
-        /* Any signal except USR1, USR2, and SIGCHLD mean break the loop.
-        */
-        if(got_signal != 0)
+        if(sig_do_stop())
         {
-            if(got_sigint || got_sigterm || got_sighup)
-            {
-                pcap_breakloop(pcap);
-                pending_break = 1;
-            }
-            else if(got_sigusr1 || got_sigusr2)
-            {
-                /* Not doing anything with these yet.
-                */
-                got_sigusr1 = got_sigusr2 = 0;
-                got_signal = 0;
-            }
-            else
-                got_signal = 0;
+            pcap_breakloop(pcap);
+            pending_break = 1;
         }
 
         res = pcap_dispatch(pcap, pcap_dispatch_count,
@@ -321,7 +310,8 @@ pcap_capture(fko_srv_options_t *opts)
 
         /* Check for any expired firewall rules and deal with them.
         */
-        check_firewall_rules(opts);
+        if(!opts->test)
+            check_firewall_rules(opts);
 
 #if FIREWALL_IPFW
         /* Purge expired rules that no longer have any corresponding
@@ -346,4 +336,6 @@ pcap_capture(fko_srv_options_t *opts)
     return(0);
 }
 
+#endif /* USE_LIBPCAP */
+
 /***EOF***/
